aboutsummaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorJoel Goddard <joel.goddard@linaro.org>2021-11-16 16:27:31 +0000
committerJoel Goddard <joel.goddard@linaro.org>2021-11-30 16:57:21 +0000
commitdbf8ffd315a5213ac885bc3f28be06a2c30ff39c (patch)
treefc81ce02ac6956bcfd66a39e4ce7056e629324ae
parent36f8a793c9ba744966aa0af530907e997b64adfd (diff)
downloadart-build-scripts-dbf8ffd315a5213ac885bc3f28be06a2c30ff39c.tar.gz
Inclusive rewording across multiple files
Some words have been deprecated in order to be more inclusive thses words have been replaced with suitable alternatives where that makes sense: * jenkins/setup_adb.sh: 'jenkins slave' -> 'jenkins agent' https://www.jenkins.io/blog/2020/06/18/terminology-update/ * tests/test_art_fuzzer.sh 'blacklist' -> 'deny list' Using black to mean excluded has racial conatations. * test/monkey/* 'blacklist' -> 'denylist' 'whitelist' -> 'allowlist' Some instances were part of 3rd partys so could not be changed. The command line option for monkey.sh has been changed. Test: ./scripts/tests/monkey/monkey.sh -a Test: ./scripts/tests/test_art_fuzzer.sh --default Change-Id: Ieb1ff4f45300525a51f7485306660ed5d9bc40ab
-rwxr-xr-xjenkins/setup_adb.sh2
-rw-r--r--tests/monkey/allowlist (renamed from tests/monkey/whitelist)0
-rw-r--r--tests/monkey/denylist (renamed from tests/monkey/blacklist)0
-rwxr-xr-xtests/monkey/monkey.sh30
-rwxr-xr-xtests/test_art_fuzzer.sh2
5 files changed, 17 insertions, 17 deletions
diff --git a/jenkins/setup_adb.sh b/jenkins/setup_adb.sh
index 8d73bb2f..16e8abf3 100755
--- a/jenkins/setup_adb.sh
+++ b/jenkins/setup_adb.sh
@@ -15,7 +15,7 @@
# See the License for the specific language governing permissions and
# limitations under the License.
-# Setup ssh connection with port forwarding for adb client on jenkins slave
+# Setup ssh connection with port forwarding for adb client on jenkins agent
# to connect to adb server on lab machine which has nexus devices connected.
#
# The script expects ANDROID_ADB_SERVER_PORT and ADB_VERSION set depending on
diff --git a/tests/monkey/whitelist b/tests/monkey/allowlist
index 4c081fef..4c081fef 100644
--- a/tests/monkey/whitelist
+++ b/tests/monkey/allowlist
diff --git a/tests/monkey/blacklist b/tests/monkey/denylist
index 7cf310f7..7cf310f7 100644
--- a/tests/monkey/blacklist
+++ b/tests/monkey/denylist
diff --git a/tests/test_art_fuzzer.sh b/tests/test_art_fuzzer.sh
index db32c17f..8975fa3e 100755
--- a/tests/test_art_fuzzer.sh
+++ b/tests/test_art_fuzzer.sh
@@ -197,7 +197,7 @@ build_seed_dex_files() {
rm -rf "${temp_folder}/seeds"
safe mkdir -p "${temp_folder}/seeds"
- log I "Excluding tests in the blacklist: ${exclude_tests}"
+ log I "Excluding tests in the deny list: ${exclude_tests}"
# Build all ART tests
safe cd art/test
diff --git a/tests/monkey/monkey.sh b/tests/monkey/monkey.sh
index f691776a..7826cfce 100755
--- a/tests/monkey/monkey.sh
+++ b/tests/monkey/monkey.sh
@@ -35,8 +35,8 @@ declare -A options_format=(
["h"]="r:&help"
["verbose"]="p:enable_verbose()"
["v"]="r:&verbose"
- ["whitelist"]="false"
- ["w"]="r:&whitelist"
+ ["allowlist"]="false"
+ ["a"]="r:&allowlist"
["time"]="${default_run_in_hours}"
["t"]="r:&time"
["kill"]="p:kill_monkey()"
@@ -63,18 +63,18 @@ usage() {
log I " -v|--verbose - verbose"
log I "-------------------------------------------"
log I "Parameters:"
- log I " -w|--whitelist - Specify which packages monkey test will run."
- log I " default: blacklist."
+ log I " -a|--allowlist - Specify which packages monkey test will run."
+ log I " default: denylist."
log I " -t|--time <time_in_hour> - Specify how long monkey test will run."
log I " default: ${default_run_in_hours}."
log I " -k|--kill - Kill the current monkey process."
log I "-------------------------------------------"
log I "For example, "
- log I "monkey.sh - Test packages excluding blacklist for 20 hours."
- log I "monkey.sh --default - Test packages excluding blacklist for 20 hours."
- log I "monkey.sh -t 2 - Test packages excluding blacklist for 2 hours."
- log I "monkey.sh -w - Test packages in the whitelist only for 20 hours."
- log I "monkey.sh -w -t 2 - Test packages in the whitelist only for 2 hours."
+ log I "monkey.sh - Test packages excluding denylist for 20 hours."
+ log I "monkey.sh --default - Test packages excluding denylist for 20 hours."
+ log I "monkey.sh -t 2 - Test packages excluding denylist for 2 hours."
+ log I "monkey.sh -a - Test packages in the allowlist only for 20 hours."
+ log I "monkey.sh -a -t 2 - Test packages in the allowlist only for 2 hours."
log I "monkey.sh -k - Kill the monkey process."
log I "-------------------------------------------"
exit 0
@@ -114,13 +114,13 @@ main() {
start_test "${timer_name}"
local package_list
- # Make a decision to use blacklist or whitelist.
- if [[ ${options["whitelist"]} = "true" ]]; then
- package_list="--pkg-whitelist-file ${target_path}/whitelist"
- safe adb push "${local_path}/whitelist" "${target_path}"
+ # Make a decision to use denylist or allowlist.
+ if [[ ${options["allowlist"]} = "true" ]]; then
+ package_list="--pkg-whitelist-file ${target_path}/allowlist"
+ safe adb push "${local_path}/allowlist" "${target_path}"
else
- package_list="--pkg-blacklist-file ${target_path}/blacklist"
- safe adb push "${local_path}/blacklist" "${target_path}"
+ package_list="--pkg-blacklist-file ${target_path}/denylist"
+ safe adb push "${local_path}/denylist" "${target_path}"
fi
local common_parameter=" -s 45 --throttle 200 --monitor-native-crashes --ignore-timeouts "